// 
// Copyright (c) 2004-2019 Jaroslaw Kowalski <jaak@jkowalski.net>, Kim Christensen, Julian Verdurmen
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions 
// are met:
// 
// * Redistributions of source code must retain the above copyright notice, 
//   this list of conditions and the following disclaimer. 
// 
// * Redistributions in binary form must reproduce the above copyright notice,
//   this list of conditions and the following disclaimer in the documentation
//   and/or other materials provided with the distribution. 
// 
// * Neither the name of Jaroslaw Kowalski nor the names of its 
//   contributors may be used to endorse or promote products derived from this
//   software without specific prior written permission. 
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
// THE POSSIBILITY OF SUCH DAMAGE.
// 

namespace NLog.Targets
{
    /// <summary>
    /// Modes of archiving files based on time.
    /// </summary>
    public enum FileArchivePeriod
    {
        /// <summary>
        /// Don't archive based on time.
        /// </summary>
        None,

        /// <summary>
        /// AddToArchive every year.
        /// </summary>
        Year,

        /// <summary>
        /// AddToArchive every month.
        /// </summary>
        Month,

        /// <summary>
        /// AddToArchive daily.
        /// </summary>
        Day,

        /// <summary>
        /// AddToArchive every hour.
        /// </summary>
        Hour,

        /// <summary>
        /// AddToArchive every minute.
        /// </summary>
        Minute,

        #region Weekdays
        /// <summary>
        /// AddToArchive every Sunday.
        /// </summary>
        Sunday,

        /// <summary>
        /// AddToArchive every Monday.
        /// </summary>
        Monday,

        /// <summary>
        /// AddToArchive every Tuesday.
        /// </summary>
        Tuesday,

        /// <summary>
        /// AddToArchive every Wednesday.
        /// </summary>
        Wednesday,

        /// <summary>
        /// AddToArchive every Thursday.
        /// </summary>
        Thursday,

        /// <summary>
        /// AddToArchive every Friday.
        /// </summary>
        Friday,

        /// <summary>
        /// AddToArchive every Saturday.
        /// </summary>
        Saturday
        #endregion 
    }
}
